@@ -9,12 +9,13 @@ convertToCheck = function(asscenario, measure, feature.steps, add.feature.costs)
     assertString(measure)
   }
   allsteps = names(asscenario$desc$feature_steps)
+  algo.allsteps = names(asscenario$desc$algorithm_feature_steps)
   if (missing(feature.steps))
     feature.steps = getDefaultFeatureStepNames(asscenario)
   else
-    assertSubset(feature.steps, allsteps)
+    assertSubset(feature.steps, c(allsteps, algo.allsteps))
   assertFlag(add.feature.costs)
-  if (add.feature.costs && is.null(asscenario$feature.costs))
+  if (add.feature.costs && is.null(asscenario$feature.costs) && is.null(asscenario$algorithm.feature.costs))
     warningf("Requested to add feature costs, but none in scenario. Adding always 0 feature costs.")
   return(list(measure = measure, feature.steps = feature.steps))
 }
